@@ -41,8 +41,6 @@
 
 #define KCONFIGCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCONFIGCORE_NO_DEPRECATED) && !defined(KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCONFIGCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGCORE_NO_DEPRECATED
-#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KCONFIGCORE_NO_DEPRECATED_WARNINGS
 #  define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCONFIGCORE_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCONFIGCORE_DEPRECATED
-#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCONFIGCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCONFIGCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
