@@ -41,8 +41,6 @@
 
 #define KCONFIGGUI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCONFIGGUI_NO_DEPRECATED) && !defined(KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCONFIGGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGGUI_NO_DEPRECATED
-#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KCONFIGGUI_NO_DEPRECATED_WARNINGS
 #  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCONFIGGUI_DEPRECATED
-#  define KCONFIGGUI_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCONFIGGUI_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCONFIGGUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
