@@ -41,8 +41,6 @@
 
 #define KCONFIGQML_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCONFIGQML_NO_DEPRECATED) && !defined(KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCONFIGQML_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGQML_NO_DEPRECATED
-#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KCONFIGQML_NO_DEPRECATED_WARNINGS
 #  define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCONFIGQML_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCONFIGQML_DEPRECATED
-#  define KCONFIGQML_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCONFIGQML_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCONFIGQML_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCONFIGQML_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
